@@ -332,7 +332,7 @@ impl IU {
     /// `ipaacar.handler.IUCallbackHandlerInterface`
     /// for more details and examples.
     fn add_callback<'p>(&self, py: Python<'p>, callback: &Bound<'p, PyAny>) -> Result<Bound<'p, PyAny>, PyErr> {
-        let module = PyModule::import_bound(py, "ipaacar")?;
+        let module = PyModule::import(py, "ipaacar")?;
         let chi = module
             .getattr("handler")?
             .getattr("IUCallbackHandlerInterface")?;
@@ -359,17 +359,17 @@ impl IU {
                 Arc::new(pyo3_asyncio::tokio::get_current_locals(p).unwrap())
             });
 
-            let callback = Py::clone(&callback);
-            let iu_id = iu.get_uid().await.to_string();
+            // let callback = Py::clone_ref(&callback, p);
+            // let iu_id = iu.get_uid().await.to_string();
             iu.on_update(move |iu: RustIUMQTT| {
                 let locals = Arc::clone(&locals);
                 let iu = IU::create_published_from_rust_iu(iu);
                 let coroutine = Python::with_gil(|p| {
-                    let chi = Py::clone(&callback);
+                    let chi = Py::clone_ref(&callback, p);
                     chi.call_method1(p, "process_iu_callback", (iu,)) // calling an async function returns the coroutine
                 })
                     .unwrap();
-                let iu_id = iu_id.clone();
+                // let iu_id = iu_id.clone();
                 Box::pin(async move {
                     let cor = Python::with_gil(|p| {
                         pyo3_asyncio::into_future_with_locals(&locals, coroutine.into_bound(p))
